Clazz.declareInterface(java.util, "List", java.util.Collection);
;//5.0.1-v2 Thu Feb 08 09:49:36 CST 2024
